Documentation
¶
Index ¶
- Constants
- func BeaconBlockHashAttribute(hash phase0.Hash32) attribute.KeyValue
- func BeaconBlockIsBlindedAttribute(isBlinded bool) attribute.KeyValue
- func BeaconBlockParentRootAttribute(root [32]byte) attribute.KeyValue
- func BeaconBlockRootAttribute(root [32]byte) attribute.KeyValue
- func BeaconBlockRootCountAttribute(count int) attribute.KeyValue
- func BeaconEpochAttribute(epoch phase0.Epoch) attribute.KeyValue
- func BeaconPeriodAttribute(period uint64) attribute.KeyValue
- func BeaconRoleAttribute(role spectypes.BeaconRole) attribute.KeyValue
- func BeaconSlotAttribute(slot phase0.Slot) attribute.KeyValue
- func BeaconVersionAttribute(version spec.DataVersion) attribute.KeyValue
- func CommitteeIDAttribute(id spectypes.CommitteeID) attribute.KeyValue
- func CommitteeIndexAttribute(index phase0.CommitteeIndex) attribute.KeyValue
- func DutyCountAttribute(count int) attribute.KeyValue
- func DutyIDAttribute(id string) attribute.KeyValue
- func DutyRoundAttribute(round specqbft.Round) attribute.KeyValue
- func Initialize(ctx context.Context, appName, appVersion string, options ...Option) (shutdown func(context.Context) error, err error)
- func InstrumentName(namespace, name string) string
- func NetworkDirectionAttribute(direction network.Direction) attribute.KeyValue
- func RoundChangeReasonAttribute(reason string) attribute.KeyValue
- func RunnerRoleAttribute(role spectypes.RunnerRole) attribute.KeyValue
- func Uint64AttributeValue(value uint64) attribute.Value
- func ValidatorCountAttribute(count int) attribute.KeyValue
- func ValidatorEventTypeAttribute(t protocolTypes.EventType) attribute.KeyValue
- func ValidatorHasQuorumAttribute(hasQuorum bool) attribute.KeyValue
- func ValidatorIndexAttribute(index phase0.ValidatorIndex) attribute.KeyValue
- func ValidatorMsgIDAttribute(msgID spectypes.MessageID) attribute.KeyValue
- func ValidatorMsgTypeAttribute(msgType spectypes.MsgType) attribute.KeyValue
- func ValidatorProposerAttribute(proposer spectypes.OperatorID) attribute.KeyValue
- func ValidatorPublicKeyAttribute(pubKey phase0.BLSPubKey) attribute.KeyValue
- type Config
- type Option
Constants ¶
const (
RunnerRoleAttrKey = "ssv.runner.role"
)
Variables ¶
This section is empty.
Functions ¶
func BeaconPeriodAttribute ¶
func BeaconRoleAttribute ¶
func BeaconRoleAttribute(role spectypes.BeaconRole) attribute.KeyValue
func BeaconVersionAttribute ¶
func BeaconVersionAttribute(version spec.DataVersion) attribute.KeyValue
func CommitteeIDAttribute ¶
func CommitteeIDAttribute(id spectypes.CommitteeID) attribute.KeyValue
func CommitteeIndexAttribute ¶
func CommitteeIndexAttribute(index phase0.CommitteeIndex) attribute.KeyValue
func DutyCountAttribute ¶
func DutyIDAttribute ¶
func Initialize ¶
func InstrumentName ¶
func RunnerRoleAttribute ¶
func RunnerRoleAttribute(role spectypes.RunnerRole) attribute.KeyValue
func Uint64AttributeValue ¶
func ValidatorCountAttribute ¶
func ValidatorEventTypeAttribute ¶
func ValidatorEventTypeAttribute(t protocolTypes.EventType) attribute.KeyValue
func ValidatorIndexAttribute ¶
func ValidatorIndexAttribute(index phase0.ValidatorIndex) attribute.KeyValue
func ValidatorMsgIDAttribute ¶
func ValidatorProposerAttribute ¶
func ValidatorProposerAttribute(proposer spectypes.OperatorID) attribute.KeyValue
Types ¶
type Option ¶
type Option func(*Config)
func WithLogger ¶
WithLogger configures the global application logger. It sets log level, format, output file settings, and enables the logger. If this option is not applied, a no-op logger will be used instead.
func WithMetrics ¶
func WithMetrics() Option
WithMetrics enables OpenTelemetry metrics collection for the application. When enabled, a Prometheus provider will be initialized. This means Prometheus will scrape metrics from a specific HTTP endpoint, so ensure the Prometheus HTTP handler is configured properly in the app.
func WithTraces ¶
func WithTraces() Option
WithTraces enables OpenTelemetry tracing for the application. When traces are enabled, the OTEL_EXPORTER_OTLP_TRACES_ENDPOINT environment variable must be set. Additional configuration can be provided through other OTEL_* environment variables as described in the official OpenTelemetry documentation.